@@ -1,9 +1,8 @@
 from ..utils import non_local_import
 
 
-def extract(filename):
-    """Extract text from docx file using
-    https://python-docx.readthedocs.org
+def extract(filename, **kwargs):
+    """Extract text from docx file using python-docx.
     """
     docx = non_local_import('docx')
     document = docx.Document(filename)
